pub fn peek_tokens(css: &str, count: usize) -> Vec<SimpleToken>Expand description
Peek at what the next few tokens would be without consuming them Enhanced debugging utility function
pub fn peek_tokens(css: &str, count: usize) -> Vec<SimpleToken>Peek at what the next few tokens would be without consuming them Enhanced debugging utility function