pub struct SeparatedParser<T: Clone + Debug + 'static, S: Clone + Debug + 'static> {
parser: TokenParser<T>,
separator: TokenParser<S>,
}Expand description
A parser that represents a main parser separated by a separator parser This allows for fluent API like: parser.separatedBy(comma).oneOrMore()
Fields
parser: TokenParser<T>separator: TokenParser<S>Implementations
Sourceimpl<T: Clone + Debug + 'static, S: Clone + Debug + 'static> SeparatedParser<T, S>
impl<T: Clone + Debug + 'static, S: Clone + Debug + 'static> SeparatedParser<T, S>
Sourcepub fn one_or_more(self) -> TokenParser<Vec<T>>
pub fn one_or_more(self) -> TokenParser<Vec<T>>
Parse one or more occurrences with separator
Sourcepub fn zero_or_more(self) -> TokenParser<Vec<T>>
pub fn zero_or_more(self) -> TokenParser<Vec<T>>
Parse zero or more occurrences with separator
Sourcepub fn as_token_parser(self) -> TokenParser<Vec<T>>
pub fn as_token_parser(self) -> TokenParser<Vec<T>>
Convert to a regular TokenParser (defaults to one or more)