pub struct TokenParser<T: Clone + Debug> {
pub run: RunFn<T>,
pub label: String,
}Fields
run: RunFn<T>label: StringImplementations
Sourceimpl<T: Clone + Debug + 'static> TokenParser<T>
impl<T: Clone + Debug + 'static> TokenParser<T>
Sourcepub fn parse(&self, css: &str) -> Result<T, CssParseError>
pub fn parse(&self, css: &str) -> Result<T, CssParseError>
Parse a CSS string using this parser
Sourcepub fn parse_to_end(&self, css: &str) -> Result<T, CssParseError>
pub fn parse_to_end(&self, css: &str) -> Result<T, CssParseError>
Parse a CSS string and ensure all input is consumed
Sourcepub fn map<U, F>(&self, f: F, label: Option<&str>) -> TokenParser<U>
pub fn map<U, F>(&self, f: F, label: Option<&str>) -> TokenParser<U>
Map the output of this parser using a function
Sourcepub fn flat_map<U, F>(&self, f: F, label: Option<&str>) -> TokenParser<U>
pub fn flat_map<U, F>(&self, f: F, label: Option<&str>) -> TokenParser<U>
Flat map operation for chaining parsers
Sourcepub fn or<U>(&self, other: TokenParser<U>) -> TokenParser<Either<T, U>>
pub fn or<U>(&self, other: TokenParser<U>) -> TokenParser<Either<T, U>>
Try this parser, or fall back to another parser
Sourcepub fn where_predicate<F>(
&self,
predicate: F,
label: Option<&str>,
) -> TokenParser<T>
pub fn where_predicate<F>( &self, predicate: F, label: Option<&str>, ) -> TokenParser<T>
Apply a predicate to filter the results
pub fn where_fn<F>(&self, predicate: F, label: Option<&str>) -> TokenParser<T>
Sourcepub fn surrounded_by<P, S>(
&self,
prefix: TokenParser<P>,
suffix: Option<TokenParser<S>>,
) -> TokenParser<T>
pub fn surrounded_by<P, S>( &self, prefix: TokenParser<P>, suffix: Option<TokenParser<S>>, ) -> TokenParser<T>
Parse with prefix and suffix parsers
Sourcepub fn skip<U>(&self, skip_parser: TokenParser<U>) -> TokenParser<T>
pub fn skip<U>(&self, skip_parser: TokenParser<U>) -> TokenParser<T>
Skip a parser after this one
Sourcepub fn prefix<P>(&self, prefix_parser: TokenParser<P>) -> TokenParser<T>
pub fn prefix<P>(&self, prefix_parser: TokenParser<P>) -> TokenParser<T>
Add a prefix parser
Sourcepub fn suffix<S>(&self, suffix_parser: TokenParser<S>) -> TokenParser<T>
pub fn suffix<S>(&self, suffix_parser: TokenParser<S>) -> TokenParser<T>
Add a suffix parser
Sourcepub fn separated_by<S: Clone + Debug + 'static>(
&self,
separator: TokenParser<S>,
) -> SeparatedParser<T, S>
pub fn separated_by<S: Clone + Debug + 'static>( &self, separator: TokenParser<S>, ) -> SeparatedParser<T, S>
Add a separator parser - creates a SeparatedParser for fluent API
Sourcepub fn debug(&self, css: &str) -> Result<T, CssParseError>
pub fn debug(&self, css: &str) -> Result<T, CssParseError>
Debug method that provides detailed parsing information Enhanced Rust-specific method for development and troubleshooting
pub fn parse_with_context(&self, css: &str) -> Result<T, CssParseError>
Sourcepub fn with_label(self, new_label: &str) -> Self
pub fn with_label(self, new_label: &str) -> Self
Enhanced labeling method for better debugging
Sourcepub fn always(value: T) -> TokenParser<T>
pub fn always(value: T) -> TokenParser<T>
Parser that always succeeds with the given value
Sourcepub fn never() -> TokenParser<T>
pub fn never() -> TokenParser<T>
Parser that always fails
pub fn separated_by_optional_whitespace(self) -> TokenParser<Vec<T>>
Sourcepub fn one_of(parsers: Vec<TokenParser<T>>) -> TokenParser<T>
pub fn one_of(parsers: Vec<TokenParser<T>>) -> TokenParser<T>
Try multiple parsers in order
Sourcepub fn sequence<U: Clone + Debug + 'static>(
parsers: Vec<TokenParser<U>>,
) -> TokenParser<Vec<U>>
pub fn sequence<U: Clone + Debug + 'static>( parsers: Vec<TokenParser<U>>, ) -> TokenParser<Vec<U>>
Parse a sequence of parsers (without separators)
Sourcepub fn sequence_with_separators<U: Clone + Debug + 'static>(
parsers: Vec<TokenParser<U>>,
) -> SequenceParsers<U>
pub fn sequence_with_separators<U: Clone + Debug + 'static>( parsers: Vec<TokenParser<U>>, ) -> SequenceParsers<U>
Parse a sequence of parsers with separator support (returns builder)
Sourcepub fn flexible_sequence_separated_by<U: Clone + Debug + 'static, S: Clone + Debug + 'static>(
parsers: Vec<Either<TokenParser<U>, TokenParser<Option<U>>>>,
separator: TokenParser<S>,
) -> TokenParser<Vec<Option<U>>>
pub fn flexible_sequence_separated_by<U: Clone + Debug + 'static, S: Clone + Debug + 'static>( parsers: Vec<Either<TokenParser<U>, TokenParser<Option<U>>>>, separator: TokenParser<S>, ) -> TokenParser<Vec<Option<U>>>
Enhanced sequence parser that can handle mixed optional/required parsers with separators This method takes a vector of Either<parser, optional_parser> to distinguish behavior
Sourcepub fn set_of<U: Clone + Debug + 'static>(
parsers: Vec<TokenParser<U>>,
) -> SetOfParsers<U>
pub fn set_of<U: Clone + Debug + 'static>( parsers: Vec<TokenParser<U>>, ) -> SetOfParsers<U>
Parse a set of parsers in any order (order-insensitive) Returns a SetOfParsers builder that can be chained with .separated_by()
Sourcepub fn zero_or_more(parser: TokenParser<T>) -> TokenParser<Vec<T>>
pub fn zero_or_more(parser: TokenParser<T>) -> TokenParser<Vec<T>>
Parse zero or more occurrences
Sourcepub fn one_or_more(parser: TokenParser<T>) -> TokenParser<Vec<T>>
pub fn one_or_more(parser: TokenParser<T>) -> TokenParser<Vec<T>>
Parse one or more occurrences
Sourcepub fn token(
expected_token: SimpleToken,
label: Option<&str>,
) -> TokenParser<SimpleToken>
pub fn token( expected_token: SimpleToken, label: Option<&str>, ) -> TokenParser<SimpleToken>
Parse a specific token type
Sourcepub fn string(expected: &str) -> TokenParser<String>
pub fn string(expected: &str) -> TokenParser<String>
Parse a specific string as an identifier
pub fn fn_name(name: &str) -> TokenParser<String>
Sourcepub fn ident() -> TokenParser<SimpleToken>
pub fn ident() -> TokenParser<SimpleToken>
Parse an identifier token
Sourcepub fn one_or_more_separated_by<S>(
parser: TokenParser<T>,
separator: TokenParser<S>,
) -> TokenParser<Vec<T>>
pub fn one_or_more_separated_by<S>( parser: TokenParser<T>, separator: TokenParser<S>, ) -> TokenParser<Vec<T>>
One or more separated by separator
Sourcepub fn zero_or_more_separated_by<S>(
parser: TokenParser<T>,
separator: TokenParser<S>,
) -> TokenParser<Vec<T>>
pub fn zero_or_more_separated_by<S>( parser: TokenParser<T>, separator: TokenParser<S>, ) -> TokenParser<Vec<T>>
Zero or more separated by separator
Sourceimpl<T: Clone + Debug + 'static> TokenParser<T>
impl<T: Clone + Debug + 'static> TokenParser<T>
Sourcepub fn optional(self) -> TokenParser<Option<T>>
pub fn optional(self) -> TokenParser<Option<T>>
Create a TokenOptionalParser from this parser
Sourceimpl<T: Clone + Debug + 'static> TokenParser<T>
impl<T: Clone + Debug + 'static> TokenParser<T>
pub fn tokens() -> Tokens
Sourcepub fn mixed_sequence<U: Clone + Debug + 'static>(
parsers: Vec<Either<TokenParser<U>, TokenParser<Option<U>>>>,
) -> MixedSequenceBuilder<U>
pub fn mixed_sequence<U: Clone + Debug + 'static>( parsers: Vec<Either<TokenParser<U>, TokenParser<Option<U>>>>, ) -> MixedSequenceBuilder<U>
Create a helper for mixed sequence parsing Usage: TokenParser::mixed_sequence([Left(foo), Right(bar.optional()), Left(baz)]).separated_by(whitespace)